==> commandir_utils_0.5.tbz: commandir_utils_0.5/commandir_record.c <==
/*  commandir_record  Version 0.5
    Initial Release Feb 9 2011
    0.2 - March 2011 - Added -g switch to specify gap
    0.3 - June 16th, 2011 - Added -s switch to specify a specific CommandIR
    0.4 - July 28th, 2011 - Added -p switch for named pipe output to /tmp/commandir0
    0.5 -  - Removed -p switch; moved to new commandird daemon
 */

#include "libcmdir.h"
#include "libtcp_client.h"
#include "libcmdir_record.h"

extern char * rec_filename;
extern int gap_size;
extern unsigned char displayOnly;
extern unsigned char pipeOnly;
// extern unsigned char incomingData[16384];

char * networkSendName;
unsigned char networkSend = 0;
unsigned char localhostPtr[] = "127.0.0.1";
unsigned char standalone = 1;



void waitForTcpRecordData() 
{
  unsigned char * dat;
  int len;
  int c;
  
  dat = malloc(16384);
  
  len = networkClientRecv(dat, 16384);
  if(displayOnly == 1)
  {
    printf("IR codes from network CommandIR (press <enter> or <Ctrl+C> to quit:\n");
  } else {
    printf("Press <enter> to accept code\n");
  }
  
  while(1)
  {
    c = kbhit();
    if(c) {
      c = getchar();
      while(kbhit())  // clear the keyboard buffer, incase they hit keys other than enter
        c = getchar();
      break;
    }
    // len should be returned when we get a terminating \0 so we know we have a full HexString
    if(len > 0) {
      dat[len] = '\0';  // Zero terminate it at the correct place!
      displayAndPipeSignal(dat, len);
    }
    usleep(10000);
    len = networkClientRecv(dat, 16384);
//    printf("Received %d bytes: (%p) %s\n", len, dat, dat);
  }
  // When it's done, return and close
}

int main(int argc, char **argv)
{
  int x, y, c;
  struct commandir_device * pcd = NULL;
  char * cmdLine;
  
  if(argc == 1)
  {
    printf("commandir_record 0.5\n\n");
    printf(" Record IR codes from a CommandIR III\n\n");

    printf("Usage: commandir_record [-sCOMMANDIR_NAME] [-gGAP_SIZE] BUTTON_NAME [BUTTON_NAME] ...\n");
    printf("       commandir_record [-sCOMMANDIR_NAME] [-gGAP_SIZE] -d\n\n");
    printf(" -gGAP_SIZE - in microseconds (us): calibrate the recorder to distinguish between repeat signals. Default: 50000\n");
    printf(" -d - Display Hex String only, do not save to file.\n");
//    printf(" -p - Pipe Hex String only, do not save to file.\n");
//    printf("    - Create a pipe by running 'mkfifo /tmp/commandir0'\n");
    printf(" -sCOMMANDIR_NAME - Record from a specific CommandIR (Firmware >=3.42 required)\n");
    printf(" -n[HostName] - Record from a CommandIR via the 'commandird' daemon.\n");
    printf("      Defaults to localhost daemon if no host is specified. \n");
    return 0;
  }
  
  // Is this a network command, or a stand-alone?
  // commandird only cares about -s and -g
  // Only for us: -d -p -n
  for(x=1;x<argc;x++)
  {
    if(argv[x][0] == '-')
    {
      switch(argv[x][1])
      {
        case 'n':
          // Network Command
              // Network send - default to localhost if none specified
          if(pipeOnly == 1) 
          {
            printf("Cannot operate in both network and pipe mode\n");
            return -1;
          }
          networkSend = 1;
          if(strlen(argv[x]) > 2) {
            networkSendName = malloc(strlen(argv[x])-1); // still 1 extra byte
            strncpy(networkSendName, &argv[x][2], strlen(argv[x]));
            networkSendName[strlen(argv[x])] = '\0';
          } else {
            networkSendName = localhostPtr;
          }

          /* CONNECT */
          if(!networkClientConnect(networkSendName)) {
            printf("Unable to connect to %s\n", networkSendName);
            return -1;
          }
          
          /* Make this easy: Pass the whole command line to the commandird server */
          cmdLine = malloc(16384);
          c = strlen("commandir_record ");
          strncpy(cmdLine, "commandir_record ", c);
          for(y=1;y<argc;y++) {
            if(argv[y][0]=='-' && argv[y][1]=='n')
              continue; // do not send the Network send flag
            c+= sprintf(&cmdLine[c], "%s ", argv[y]);
          }
          cmdLine[c++] = '\0';
          networkClientSend(cmdLine, c);
          
          break;
        case 'd':
          // Display Only - don't save to a file
          displayOnly = 1;
          break;
/*        case 'p':
          // Send to pipe - don't save to a file
          if(networkSend == 1) 
          {
            printf("Cannot operate in both network and pipe mode\n");
            return -1;
          }
          pipeOnly = 1;
          break;
 */
      }
    } else {
      // If it's not a switch, it's a filename
      if(displayOnly) {
        printf("Do not specify a filename if you want to display codes with -d.\n");
        return -1;
      }
      if(pipeOnly) {
        printf("Do not specify a filename if you want to pipe with -p.\n");
        return -1; 
      }
      rec_filename = argv[x];
      printf("Recording %s ...\n", rec_filename);
      if(networkSend == 1) 
      {
        // Multiple recording from via network
        
        printf("File name should be set; waiting for data?\n");

        // NO, WAIT for data
        waitForTcpRecordData();        
        // We don't close TCP; we might want to record another key
        
      } else {
        // Stand-alone, easy recording
        if(pcd)
          commandir_rec(pcd->cmdir_udev);
        else
          commandir_rec(NULL);
      }
    }
  }
  
  printf("Status: networkSend: %d, displayOnly: %d, pipeOnly: %d\n", networkSend, displayOnly, pipeOnly);
  
  if(networkSend == 1) 
  {
    if(displayOnly == 1) 
    {
      /* This case is for continuous operation - display or pipe only */
      waitForTcpRecordData();
    }
    networkClientClose();
    return 0;  
  }
  
  
  
  printf("commandir_record shoud not run execute_commandir_record_arg\n");
  return 0;
  
  // Stand-alone local command:
  execute_commandir_record_arg(argc, argv);
    
  return 0;
  
}

==> commandir_utils_0.6.tbz: commandir_utils_0.6/commandir_record.c <==
/*  commandir_record  Version 0.5
    Initial Release Feb 9 2011
    0.2 - March 2011 - Added -g switch to specify gap
    0.3 - June 16th, 2011 - Added -s switch to specify a specific CommandIR
    0.4 - July 28th, 2011 - Added -p switch for named pipe output to /tmp/commandir0
    0.5 -  - Removed -p switch; moved to new commandird daemon
 */

#include "cmdirutils_version.h"
#include "libcmdir.h"
#include "libtcp_client.h"
#include "libcmdir_record.h"

extern char * rec_filename;
extern int gap_size;
extern unsigned char displayOnly;
extern unsigned char pipeOnly;
// extern unsigned char incomingData[16384];

char * networkSendName;
unsigned char networkSend = 0;
unsigned char localhostPtr[] = "127.0.0.1";
unsigned char standalone = 1;


extern char determining_gap;


void waitForTcpRecordData() 
{
  unsigned char * dat;
  int displayed;
  int len;
  int c;
  
  dat = malloc(16384);
  
  len = networkClientRecv(dat, 16384);
  if(displayOnly == 1)
  {
    printf("IR codes from network CommandIR (press <enter> or <Ctrl+C> to quit:\n");
  } else {
    printf("Press <enter> to accept code\n");
  }
  
  while(1)
  {
    c = kbhit();
    if(c) {
      c = getchar();
      while(kbhit())  // clear the keyboard buffer, incase they hit keys other than enter
        c = getchar();
      break;
    }
    // len should be returned when we get a terminating \0 so we know we have a full HexString
    // Note that the network might return multiple signals!
    if(len > 0) {
      dat[len] = '\0';  // Zero terminate it at the correct place!
      displayed = 0;
      while(displayed < len) {
        // gap is encoded in file!
        displayAndPipeSignal(&dat[displayed], strlen(&dat[displayed]), 0);  
        displayed += strlen(&dat[displayed]) + 1;  // +1?
      }
    }
    usleep(5000);
    len = networkClientRecv(dat, 16384);
//    printf("Received %d bytes: (%p) %s\n", len, dat, dat);
  }
  // When it's done, return and close
}

int main(int argc, char **argv)
{
  int x, y, c;
  struct commandir_device * pcd = NULL;
  char * cmdLine;
  
  if(argc == 1)
  {
    printf("commandir_record %s\n\n", utils_version);
    printf(" Record IR codes from a CommandIR III\n\n");

    printf("Usage: commandir_record [-n] [-sCOMMANDIR_NAME] [-gGAP_SIZE] BUTTON_NAME [BUTTON_NAME] ...\n");
    printf("       commandir_record [-n] [-sCOMMANDIR_NAME] [-gGAP_SIZE] -d\n\n");
    printf(" -gGAP_SIZE - in microseconds (us): calibrate the recorder to distinguish between repeat signals. Default: 50000\n");
    printf("            - If -g is not specified, commandir_record will try to determine it.\n");
    printf(" -d - Display Hex String only, do not save to file.\n");
//    printf(" -r - Display Raw Codes only, do not save to file.\n");

//    printf(" -p - Pipe Hex String only, do not save to file.\n");
//    printf("    - Create a pipe by running 'mkfifo /tmp/commandir0'\n");
    printf(" -sCOMMANDIR_NAME - Record from a specific CommandIR (Firmware >=3.42 required)\n");
    printf(" -n[HostName] - Record from a CommandIR via the 'commandird' daemon.\n");
    printf("      Defaults to localhost daemon if no host is specified. \n");
    return 0;
  }
  
  // Is this a network command, or a stand-alone?
  // commandird only cares about -s and -g
  // Only for us: -d -p -n
  for(x=1;x<argc;x++)
  {
    if(argv[x][0] == '-')
    {
      switch(argv[x][1])
      {
        case 'n':
          // Network Command
              // Network send - default to localhost if none specified
          if(pipeOnly == 1) 
          {
            printf("Cannot operate in both network and pipe mode\n");
            return -1;
          }
          networkSend = 1;
          if(strlen(argv[x]) > 2) {
            networkSendName = malloc(strlen(argv[x])-1); // still 1 extra byte
            strncpy(networkSendName, &argv[x][2], strlen(argv[x]));
            networkSendName[strlen(argv[x])] = '\0';
          } else {
            networkSendName = localhostPtr;
          }

          /* CONNECT */
          if(!networkClientConnect(networkSendName)) {
            printf("Unable to connect to %s\n", networkSendName);
            return -1;
          }
          
          /* Make this easy: Pass the whole command line to the commandird server */
          cmdLine = malloc(16384);
          c = strlen("commandir_record ");
          strncpy(cmdLine, "commandir_record ", c);
          for(y=1;y<argc;y++) {
            if(argv[y][0]=='-' && argv[y][1]=='n')
              continue; // do not send the Network send flag
            c+= sprintf(&cmdLine[c], "%s ", argv[y]);
          }
          cmdLine[c++] = '\0';
          networkClientSend(cmdLine, c);
          
          break;
        case 'd':
          // Display Only - don't save to a file
          displayOnly = 1;
          break;
/*        case 'p':
          // Send to pipe - don't save to a file
          if(networkSend == 1) 
          {
            printf("Cannot operate in both network and pipe mode\n");
            return -1;
          }
          pipeOnly = 1;
          break;
 */
      }
    } else {
      // If it's not a switch, it's a filename
      if(displayOnly) {
        printf("Do not specify a filename if you want to display codes with -d.\n");
        return -1;
      }
      if(pipeOnly) {
        printf("Do not specify a filename if you want to pipe with -p.\n");
        return -1; 
      }
      rec_filename = argv[x];
      printf("Recording %s ...\n", rec_filename);
      if(networkSend == 1) 
      {
        // Multiple recording from via network
        
        waitForTcpRecordData();        
      } /* else {   - let execute_commandir_record_arg handle this
        // Stand-alone, easy recording
        if(pcd)
          commandir_rec(pcd->cmdir_udev);
        else
          commandir_rec(NULL);
      } */  
    }
  }
  
  if(networkSend == 1) 
  {
    if(displayOnly == 1) 
    {
      /* This case is for continuous operation - display or pipe only */
      waitForTcpRecordData();
    }
    networkClientClose();
    return 0;  
  } else {
    printf("commandir_record %s\n\n", utils_version);
  
  }
  
  
  
//  printf("commandir_record shoud not run execute_commandir_record_arg\n");
//  return 0;
  
  // Stand-alone local command:
  execute_commandir_record_arg(argc, argv);
    
  return 0;
  
}
